@@ -14,13 +14,13 @@ test_that("output is valid geometry", {
   output <- gs_voronoi(anchor = coords, window = window)
   expect_class(output, classes = "geom")
   expect_true(output@type == "polygon")
-  expect_data_frame(output@feature, any.missing = FALSE, nrows = 4, ncols = 2)
+  expect_data_frame(output@feature$geometry, any.missing = FALSE, nrows = 4, ncols = 2)
 
   # create voronoi from geom
   output <- gs_voronoi(anchor = input)
   expect_class(output, classes = "geom")
   expect_true(output@type == "polygon")
-  expect_data_frame(output@feature, any.missing = FALSE, nrows = 4, ncols = 2)
+  expect_data_frame(output@feature$geometry, any.missing = FALSE, nrows = 4, ncols = 2)
 })
 
 test_that("Error if arguments have wrong value", {
