@@ -5,9 +5,8 @@ context("visualise")
 
 
 test_that("visualise a Raster* object", {
-  continuous <<- gtRasters$continuous
 
-  output <- visualise(raster = continuous)
+  output <- visualise(raster = gtRasters$continuous)
   expect_class(output, "recordedplot")
 
   input <- brick(system.file("external/rlogo.grd", package="raster"))
@@ -16,14 +15,14 @@ test_that("visualise a Raster* object", {
 })
 
 test_that("visualise a matrix", {
-  aMatrix <<- raster::as.matrix(gtRasters$continuous)
+  aMatrix <- raster::as.matrix(gtRasters$continuous)
 
   output <- visualise(`my matrix` = aMatrix)
   expect_class(output, "recordedplot")
 })
 
 test_that("visualise an image", {
-  continuous <<- gtRasters$categorical
+  continuous <- gtRasters$categorical
   input <<- brick(system.file("external/rlogo.grd", package="raster"))
 
   output <- visualise(raster = input, image = TRUE)
@@ -34,7 +33,7 @@ test_that("visualise a geom", {
   coords <- data.frame(x = c(40, 70, 70, 50),
                        y = c(40, 40, 60, 70),
                        fid = 1)
-  input <<- gs_polygon(anchor = coords)
+  input <- gs_polygon(anchor = coords)
 
   output <- visualise(geom = input, clip = FALSE)
   expect_class(output, "recordedplot")
@@ -86,9 +85,8 @@ test_that("visualise a geom on top of an already plotted raster", {
 
 test_that("output the history of a plotted object", {
   # from a RasterLayer
-  continuous <<- gtRasters$continuous
 
-  output <- capture_message(visualise(continuous, trace = TRUE))
+  output <- capture_message(visualise(gtRasters$continuous, trace = TRUE))
   expect_class(output, "simpleMessage")
 
   # from a RasterBrick
@@ -98,10 +96,10 @@ test_that("output the history of a plotted object", {
   # from a geom
   coords <- data.frame(x = c(40, 70, 70, 50),
                        y = c(40, 40, 60, 70))
-  aGeom <<- gs_polygon(anchor = coords)
+  aGeom <- gs_polygon(anchor = coords)
 
-  output <- capture_message(visualise(bla = aGeom, trace = TRUE))
-  expect_class(output, "simpleMessage")
+  output <- capture_messages(visualise(bla = aGeom, trace = TRUE))
+  expect_character(x = output, pattern = "this object has the following history:\n -> object was created as 'polygon' geom.\n")
 
   input <- brick(system.file("external/rlogo.grd", package="raster"))
   input@history <- list("bla")
